summaryrefslogtreecommitdiffstats
path: root/ash/wm/system_modal_container_layout_manager.h
diff options
context:
space:
mode:
authorvollick@google.com <vollick@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-01 17:19:22 +0000
committervollick@google.com <vollick@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-01 17:19:22 +0000
commitc3287f6e7f7c23c1f20729d4729ffdd84658c4b7 (patch)
treed3cd8bb3f63836aaa4058e2834c8ba28791ffc23 /ash/wm/system_modal_container_layout_manager.h
parent32b9c269a98692acf748f7594425d586e838cf96 (diff)
downloadchromium_src-c3287f6e7f7c23c1f20729d4729ffdd84658c4b7.zip
chromium_src-c3287f6e7f7c23c1f20729d4729ffdd84658c4b7.tar.gz
chromium_src-c3287f6e7f7c23c1f20729d4729ffdd84658c4b7.tar.bz2
Disable animations during aura tests.
This causes all animations scheduled during a test to complete immediately. After making this change, I noticed some code assumed that animations would not complete synchronously. Some of this code used animation observers, and I while fixing the code I have updated it to use the preferred ImplicitAnimationObserver. BUG=None TEST=aura_shell_unittests,aura_unittests,compositor_unittests Review URL: https://chromiumcodereview.appspot.com/9222018 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@120074 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/wm/system_modal_container_layout_manager.h')
-rw-r--r--ash/wm/system_modal_container_layout_manager.h11
1 files changed, 3 insertions, 8 deletions
diff --git a/ash/wm/system_modal_container_layout_manager.h b/ash/wm/system_modal_container_layout_manager.h
index c713500..309d0f07 100644
--- a/ash/wm/system_modal_container_layout_manager.h
+++ b/ash/wm/system_modal_container_layout_manager.h
@@ -35,7 +35,7 @@ namespace internal {
class ASH_EXPORT SystemModalContainerLayoutManager
: public aura::LayoutManager,
public aura::WindowObserver,
- public ui::LayerAnimationObserver,
+ public ui::ImplicitAnimationObserver,
public SystemModalContainerEventFilterDelegate {
public:
explicit SystemModalContainerLayoutManager(aura::Window* container);
@@ -55,13 +55,8 @@ class ASH_EXPORT SystemModalContainerLayoutManager
const char* key,
void* old) OVERRIDE;
- // Overridden from ui::LayerAnimationObserver:
- virtual void OnLayerAnimationEnded(
- const ui::LayerAnimationSequence* sequence) OVERRIDE;
- virtual void OnLayerAnimationAborted(
- const ui::LayerAnimationSequence* sequence) OVERRIDE;
- virtual void OnLayerAnimationScheduled(
- const ui::LayerAnimationSequence* sequence) OVERRIDE;
+ // Overridden from ui::ImplicitAnimationObserver:
+ virtual void OnImplicitAnimationsCompleted() OVERRIDE;
// Overridden from SystemModalContainerEventFilterDelegate:
virtual bool CanWindowReceiveEvents(aura::Window* window) OVERRIDE;